package models_utils

import (
	"database/sql"
	"errors"
)

type BaseModel struct {
	Name   string
	Status int
	Id     string

	ImageMode int
	Width     int
	Height    int
	Format    string
}

const (
	FAILED_TRAINING           = -4
	FAILED_PREPARING_TRAINING = -3
	FAILED_PREPARING_ZIP_FILE = -2
	FAILED_PREPARING          = -1

	PREPARING            = 1
	CONFIRM_PRE_TRAINING = 2
	PREPARING_ZIP_FILE   = 3
	TRAINING             = 4
	READY                = 5
)

var ModelNotFoundError = errors.New("Model not found error")

func GetBaseModel(db *sql.DB, id string) (base *BaseModel, err error) {
	rows, err := db.Query("select name, status, id, width, height, color_mode, format from models where id=$1;", id)
	if err != nil { return }
	defer rows.Close()

	if !rows.Next() { return nil, ModelNotFoundError }

	base = &BaseModel{}
	var colorMode string
	err = rows.Scan(&base.Name, &base.Status, &base.Id, &base.Width, &base.Height, &colorMode, &base.Format)
	if err != nil {
		return nil, err
	}

	base.ImageMode = StringToImageMode(colorMode)
	return
}

func StringToImageMode(colorMode string) int {
	switch colorMode {
	case "greyscale":
		return 1
	case "rgb":
		return 3
	default:
		panic("unkown color mode")
	}
}
